==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fil/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Ang mga asset na nakatalaga sa :name',
    'bulk_update_warn'	=> 'Ikaw ay mag-edit ng mga katangian ng :user_count mga gumagamit. Mangyaring tandaan na hindi mo maaaring mabago ang iyong sariling user attributes gamit ang form na ito, at kinakailangang magsagawa ng pag-edit sa iyong sariling user nang mag-isa.',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang gumagamit ng isang beses. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago.',
    'current_assets'    => 'Ang assets ay kasalukuyang nai-check out sa gumagamit na ito',
    'clone'             => 'I-clone ang User',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'I-edit ang Gumamit',
    'filetype_info'     => 'Ang mga pinapayagang uri ng file ay png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, at rar.',
    'history_user'      => 'Ang kasaysayan para sa :name',
	'info'				=> 'Impormasyon',
    'restore_user'		=> 'I-klik dito upang maibalik ang mga ito.',
    'last_login'        => 'Ang Huling Pag-login',
    'ldap_config_text'  => 'Pwedeng makita ang configuration settings ng LDAP Admin > Settings. Ang (opsyonal) napiling lokasyon ay itatakda para sa lahat ng mga na-import na mga gumagamit o user.',
    'print_assigned'    => 'I-print ang Lahat ng Nakatalaga',
    'software_user'     => 'Ang Software ay Nai-check out sa :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tingnan ang User :name',
    'usercsv'           => 'Ang CSV file',
    'two_factor_admin_optin_help' => 'Ang iyong kasalukuyang mga admin settings ay napapahintulot ng selektibong pagpapatupad ng two-factor authentication.  ',
    'two_factor_enrolled' => 'Ang Na-enroll na 2FA Device ',
    'two_factor_active'   => 'Ang 2FA Active ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fil/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Ang mga asset na nakatalaga sa :name',
    'bulk_update_warn'	=> 'Ikaw ay mag-edit ng mga katangian ng :user_count mga gumagamit. Mangyaring tandaan na hindi mo maaaring mabago ang iyong sariling user attributes gamit ang form na ito, at kinakailangang magsagawa ng pag-edit sa iyong sariling user nang mag-isa.',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang gumagamit ng isang beses. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago.',
    'current_assets'    => 'Ang assets ay kasalukuyang nai-check out sa gumagamit na ito',
    'clone'             => 'I-clone ang User',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'I-edit ang Gumamit',
    'filetype_info'     => 'Ang mga pinapayagang uri ng file ay png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, at rar.',
    'history_user'      => 'Ang kasaysayan para sa :name',
    'info'				=> 'Impormasyon',
    'restore_user'		=> 'I-klik dito upang maibalik ang mga ito.',
    'last_login'        => 'Ang Huling Pag-login',
    'ldap_config_text'  => 'Pwedeng makita ang configuration settings ng LDAP Admin > Settings. Ang (opsyonal) napiling lokasyon ay itatakda para sa lahat ng mga na-import na mga gumagamit o user.',
    'print_assigned'    => 'I-print ang Lahat ng Nakatalaga',
    'software_user'     => 'Ang Software ay Nai-check out sa :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tingnan ang User :name',
    'usercsv'           => 'Ang CSV file',
    'two_factor_admin_optin_help' => 'Ang iyong kasalukuyang mga admin settings ay napapahintulot ng selektibong pagpapatupad ng two-factor authentication.  ',
    'two_factor_enrolled' => 'Ang Na-enroll na 2FA Device ',
    'two_factor_active'   => 'Ang 2FA Active ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
